<?php

/**
 * Test: Table: Caching.
 *
 * @author     Jakub Vrana
 * @author     Jan Skrasek
 * @package    Nette\Database
 * @multiple   databases.ini
 */

require dirname(__FILE__) . '/connect.inc.php'; // create $connection

DatabaseHelpers::loadFromFile($connection, dirname(__FILE__) . "/{$driverName}-nette_test1.sql");



$cacheStorage = new MemoryStorage;
$connection->setCacheStorage($cacheStorage);
$connection->setDatabaseReflection(new DiscoveredReflection($cacheStorage));



// Testing Selection caching
$bookSelection = $connection->table('book')->find(2);
switch ($driverName) {
	case 'mysql':
		Assert::same('SELECT * FROM `book` WHERE (`id` = ?)', $bookSelection->getSql());
		break;
	case 'pgsql':
		Assert::same('SELECT * FROM "book" WHERE ("id" = ?)', $bookSelection->getSql());
		break;
}


$book = $bookSelection->fetch();
$book->title;
$book->translator;
$bookSelection->__destruct();
$bookSelection = $connection->table('book')->find(2);
switch ($driverName) {
	case 'mysql':
		Assert::same('SELECT `id`, `title`, `translator_id` FROM `book` WHERE (`id` = ?)', $bookSelection->getSql());
		break;
	case 'pgsql':
		Assert::same('SELECT "id", "title", "translator_id" FROM "book" WHERE ("id" = ?)', $bookSelection->getSql());
		break;
}


$book = $bookSelection->fetch();
$book->author_id;
switch ($driverName) {
	case 'mysql':
		Assert::same('SELECT * FROM `book` WHERE (`id` = ?)', $bookSelection->getSql());
		break;
	case 'pgsql':
		Assert::same('SELECT * FROM "book" WHERE ("id" = ?)', $bookSelection->getSql());
		break;
}

$bookSelection->__destruct();
$bookSelection = $connection->table('book')->find(2);
switch ($driverName) {
	case 'mysql':
		Assert::same('SELECT `id`, `title`, `translator_id`, `author_id` FROM `book` WHERE (`id` = ?)', $bookSelection->getSql());
		break;
	case 'pgsql':
		Assert::same('SELECT "id", "title", "translator_id", "author_id" FROM "book" WHERE ("id" = ?)', $bookSelection->getSql());
		break;
}



// Testing GroupedSelection reinvalidation caching
foreach ($connection->table('author') as $author) {
	$stack[] = $selection = $author->related('book.author_id')->order('title');
	foreach ($selection as $book) {
		$book->title;
	}
}

reset($stack)->__destruct();


$books = array();
foreach ($connection->table('author') as $author) {
	foreach ($author->related('book.author_id')->order('title') as $book) {
		if ($book->author_id == 12) {
			$books[$book->title] = $book->translator_id; // translator_id is new used column in the second loop
		}
	}
}

Assert::same(array(
	'Dibi' => 12,
	'Nette' => 12,
), $books);



$cacheStorage = new MemoryStorage;
$connection->setCacheStorage($cacheStorage);



$relatedStack = array();
foreach ($connection->table('author') as $author) {
	$relatedStack[] = $related = $author->related('book.author_id');
	foreach ($related as $book)	{
		$book->id;
	}
}

foreach ($relatedStack as $related) {
	$property = $related->reflection->getProperty('accessed');
	$property->setAccessible(true);
	// checks if instances have shared data of accessed columns
	Assert::same(array('id', 'author_id'), array_keys($property->getValue($related)));
}
