<?php

/**
 * Test: User authentication.
 *
 * @author     David Grudl
 * @package    Nette\Http
 */



require dirname(__FILE__) . '/../bootstrap.php';



// Setup environment
$_COOKIE = array();
ob_start();



class Authenticator implements IAuthenticator
{
	/*
	 * @param  array
	 * @return IIdentity
	 * @throws AuthenticationException
	 */
	function authenticate(array $credentials)
	{
		list($username, $password) = $credentials;
		if ($username !== 'john') {
			throw new AuthenticationException('Unknown user', self::IDENTITY_NOT_FOUND);

		} elseif ($password !== 'xxx') {
			throw new AuthenticationException('Password not match', self::INVALID_CREDENTIAL);

		} else {
			return new Identity('John Doe', 'admin');
		}
	}

}



function onLoggedIn($user) {
	// TODO: add test
}



function onLoggedOut($user) {
	// TODO: add test
}



$container = id(new Configurator)->setTempDirectory(TEMP_DIR)->createContainer();

$user = $container->user;
$user->onLoggedIn[] = 'onLoggedIn';
$user->onLoggedOut[] = 'onLoggedOut';


Assert::false( $user->isLoggedIn() );
Assert::null( $user->getIdentity() );
Assert::null( $user->getId() );



// authenticate
Assert::throws(create_function('', 'extract(NCFix::$vars['.NCFix::uses(array('user'=>$user)).'], EXTR_REFS);
	// login without handler
	$user->login(\'jane\', \'\');
'), 'InvalidStateException', 'Service of type IAuthenticator not found.');

$handler = new Authenticator;
$user->setAuthenticator($handler);

Assert::throws(create_function('', 'extract(NCFix::$vars['.NCFix::uses(array('user'=>$user)).'], EXTR_REFS);
	// login as jane
	$user->login(\'jane\', \'\');
'), 'AuthenticationException', 'Unknown user');

Assert::throws(create_function('', 'extract(NCFix::$vars['.NCFix::uses(array('user'=>$user)).'], EXTR_REFS);
	// login as john
	$user->login(\'john\', \'\');
'), 'AuthenticationException', 'Password not match');

// login as john#2
$user->login('john', 'xxx');
Assert::true( $user->isLoggedIn() );
Assert::equal( new Identity('John Doe', 'admin'), $user->getIdentity() );
Assert::same( 'John Doe', $user->getId() );

// login as john#3
$user->logout(TRUE);
$user->login( new Identity('John Doe', 'admin') );
Assert::true( $user->isLoggedIn() );
Assert::equal( new Identity('John Doe', 'admin'), $user->getIdentity() );



// log out
// logging out...
$user->logout(FALSE);

Assert::false( $user->isLoggedIn() );
Assert::equal( new Identity('John Doe', 'admin'), $user->getIdentity() );


// logging out and clearing identity...
$user->logout(TRUE);

Assert::false( $user->isLoggedIn() );
Assert::null( $user->getIdentity() );



// namespace
// login as john#2?
$user->login('john', 'xxx');
Assert::true( $user->isLoggedIn() );


// setNamespace(...)
$user->getStorage()->setNamespace('other');

Assert::false( $user->isLoggedIn() );
Assert::null( $user->getIdentity() );
