<?php

/**
 * Test: PhpHelpers::format() & formatArgs()
 *
 * @author     David Grudl
 * @package    Nette\Utils
 */



require dirname(__FILE__) . '/../bootstrap.php';


Assert::same( 'func', PhpHelpers::format('func') );
Assert::same( 'func(1)', PhpHelpers::format('func(?)', 1, 2) );

Assert::same( 'func', PhpHelpers::formatArgs('func', array(1, 2)) );
Assert::same( 'func(1)', PhpHelpers::formatArgs('func(?)', array(1, 2)) );
Assert::same( "func(array(\n\t1,\n\t2,\n))", PhpHelpers::formatArgs('func(?)', array(array(1, 2))) );
Assert::same( 'func(1, 2)', PhpHelpers::formatArgs('func(?*)', array(array(1, 2))) );

Assert::throws(create_function('', '
	PhpHelpers::formatArgs(\'func(?*)\', array(1, 2));
'), 'InvalidArgumentException', 'Argument must be an array.');

Assert::throws(create_function('', '
	PhpHelpers::formatArgs(\'func(?, ?, ?)\', array(1, 2));
'), 'InvalidArgumentException', 'Insufficient number of arguments.');

Assert::same( '$a = 2', PhpHelpers::formatArgs('$? = ?', array('a', 2)) );
Assert::same( '$obj->a = 2', PhpHelpers::formatArgs('$obj->? = ?', array('a', 2)) );
Assert::same( '$obj->{1} = 2', PhpHelpers::formatArgs('$obj->? = ?', array(1, 2)) );
Assert::same( '$obj->{\' \'} = 2', PhpHelpers::formatArgs('$obj->? = ?', array(' ', 2)) );

Assert::same( "Item", PhpHelpers::formatMember('Item') );
Assert::same( "{'0Item'}", PhpHelpers::formatMember('0Item') );

Assert::true( PhpHelpers::isIdentifier('Item') );
Assert::false( PhpHelpers::isIdentifier('0Item') );
